@@ -34,8 +34,8 @@ class PhotosLibrary:
 
     @property
     def version(self):
-        """ version of Photos.app """
-        return run_script("_photoslibrary_version")
+        """ version of Photos.app as str """
+        return str(run_script("_photoslibrary_version"))
 
     @property
     def frontmost(self):
@@ -98,9 +98,11 @@ class PhotosLibrary:
         """import photos
 
         Args:
-            photos: list of file paths to import
+            photo_paths: list of file paths to import
             album: optional, Album object for album to import into
-            skip_duplicate_check: if True, Photos will not check for duplicates on import, default is False
+            skip_duplicate_check: if True, Photos will not check for duplicates on import, default is False. 
+            NOTE: If you attempt to import a duplicate photo and skip_duplicate_check != True, 
+            Photos will block with drop-down sheet until the user clicks "Cancel, Import, or Don't Import."
         """
         if album is not None:
             run_script(
@@ -306,6 +308,36 @@ class PhotosLibrary:
             folder = subfolder
         return folder
 
+    def make_album_folders(self, album_name, folder_path):
+        """Make album in a folder path.  If either the album or any component of the
+           folder path doesn't exist, it will be created.  If album or folder path 
+           does exist, no duplicate is created.  Folder path is created recursively
+           if needed.
+
+        Args:
+            album_name: name of album to create.  If album already exists, returns existing album.
+            folder_path: list of folder names in descending path order, e.g. ["Folder", "SubFolder1", "SubFolder2"].
+
+        Returns:
+            Album object.
+        
+        Raises:
+            ValueError if folder_path is empty or album_name is None.
+            TypeError if folder_path is not a list.
+        """
+        if album_name is None or not len(album_name):
+            raise ValueError("album_name must not be None")
+        if not isinstance(folder_path, list):
+            raise TypeError("list expected for folder_path")
+        if not folder_path:
+            raise ValueError("no values in folder_path")
+
+        folder = self.make_folders(folder_path)
+        album = folder.album(album_name)
+        if album is None:
+            album = folder.create_album(album_name)
+        return album
+
     def delete_folder(self, folder):
         """Deletes folder (Not yet implemented)
 
@@ -401,7 +433,6 @@ class Album:
 
         return run_script("_album_get_path", self.id, delim)
 
-    @property
     def photos(self):
         """ list of Photo objects for photos contained in album """
         photo_ids = run_script("_album_photos", self.id)
